@@ -1,4 +1,9 @@
-from .core import gerar_df_phoenix
+from .core import (
+    gerar_df_phoenix,
+    abrir_planilha,
+    tratar_colunas_df,
+    gsheet_to_df
+)
 
 __all__ = [
     "gerar_df_phoenix",
